@@ -413,11 +413,11 @@ def assign_annotation (identity_cutoff, coverage_cutoff, cluster, uniref, anns,
 				if "UniRef90_unknown" in ann_type[myclust]:
 					if mytype == "UniRef90_characterized":
 						# debut
-						print("Change characterized type to unknown!\t" + myclust + "\t" + gene_id)
+						config.logger.info ("Change characterized type to unknown!\t" + myclust + "\t" + gene_id)
 						mytype = "UniRef90_weak_homology"
 					if mytype == "UniRef90_uncharacterized":
 						# debut
-						print("Change uncharacterized type to unknown!\t" + myclust + "\t" + gene_id)
+						config.logger.info ("Change uncharacterized type to unknown!\t" + myclust + "\t" + gene_id)
 						mytype = "UniRef90_weak_homology"
 				if mytype == "UniRef90_weak_homology":
 					anns[myclust] = mystr
@@ -516,7 +516,7 @@ def assign_annotation (identity_cutoff, coverage_cutoff, cluster, uniref, anns,
 						taxa_id = "NA"
 						open_out2.write(pre_line + "\t" + taxa_id + "\t" + taxa_name + "\t" + taxa_rank + "\t" + taxa_lineage + "\t" + mynote + "\n")
 			else:
-				print("No uniref ID info!\t" + myclust)
+				config.logger.info ("WARNING! No uniref ID info!\t" + myclust)
 	# cluster name
 	# foreach peptide cluster
 	open_out.close()
@@ -538,22 +538,22 @@ def main():
 	if values.study:
 		mystudy = values.study
 
-	sys.stderr.write("### Start summary_protein_family_uniref_annotation.py -a " + values.annotation + " ####\n")
+	config.logger.info ("#### Start summary_protein_family_uniref_annotation step ####")
 
 	### collect cluster info ###
-	sys.stderr.write("Get info ......starting\n")
+	config.logger.info ("Get info ......starting")
 	pep_cluster = collect_pep_cluster_info (myfamily)
 	anns, ann_type, hits, uniref_taxa, taxa_hits  = collect_ann_info (values.annotation, values.type)
 	taxa, taxa_map = collect_taxonomy_info (config.taxonomy_database, taxa_hits)
 	uniref = collect_uniref_mapping_info (values.mapping, uniref_taxa, taxa, taxa_map)
-	sys.stderr.write("Get info ......done\n")
+	config.logger.info ("Get info ......done")
 
 	### assign annotation to peptide families ###
-	sys.stderr.write("\nAssign annotation to peptide families ......starting\n")
+	config.logger.info ("Assign annotation to peptide families ......starting")
 	assign_annotation(config.tshld_identity, config.tshld_coverage, pep_cluster, uniref, anns, ann_type, taxa, taxa_map, mystudy, values.output)
-	sys.stderr.write("\nAssign annotation to peptide families ......done\n")
+	config.logger.info ("Assign annotation to peptide families ......done")
 
-	sys.stderr.write("### Finish summary_protein_family_uniref_annotation.py ####\n\n\n")
+	config.logger.info ("### Finish summary_protein_family_uniref_annotation step ####")
 
 # end: main
 
